\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{exsheetmult}[2018/04/17 Template for written exercises in computer science]

\LoadClass[a4paper, 12pt]{article}

\RequirePackage{amsmath}
\RequirePackage[T1]{fontenc}
\RequirePackage[utf8x]{inputenc}
\RequirePackage[english,ngerman]{babel}
\RequirePackage[babel,german=quotes]{csquotes}
\usepackage{ifthen}

\RequirePackage{marginnote}
\RequirePackage{fancyhdr}

\RequirePackage{geometry}
\geometry{a4paper, headheight=15.2pt, footskip=30pt, left=1cm,right=3.5cm,top=2.54cm,bottom=2cm}
\DeclareOption{largelinewidth}{\renewcommand{\baselinestretch}{1.5}}
\DeclareOption{densemargins}{\newgeometry{headheight=15.2pt, footskip=30pt, left=1cm,right=1cm,top=2.54cm,bottom=2cm}}
\DeclareOption{english}{\selectlanguage{english}}
\providecommand{\UEGroupIntr}{Abgebende Person}

\DeclareOption{difffonts}{}
\DeclareOption{group}{\renewcommand{\UEGroupIntr}{Gruppenteilnehmende}}
\DeclareOption{singleex}{}
\DeclareOption{studon}{}
\DeclareOption{studiengang}{}
\DeclareOption{doublelogo}{}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

\makeatletter
\newif\ifsingleex
\@ifclasswith{exsheetmult}{singleex}{\singleextrue}{\singleexfalse}
\newif\ifdifffonts
\@ifclasswith{exsheetmult}{difffonts}{\difffontstrue}{\difffontsfalse}
\newif\ifstudon
\@ifclasswith{exsheetmult}{studon}{\studontrue}{\studonfalse}
\newif\ifstudiengang
\@ifclasswith{exsheetmult}{studiengang}{\studiengangtrue}{\studiengangfalse}
\newif\ifmatrikelnummer
\@ifclasswith{exsheetmult}{matnr}{\matrikelnummertrue}{\matrikelnummerfalse}
\newif\ifdoublelogo
\@ifclasswith{exsheetmult}{doublelogo}{\doublelogotrue}{\doublelogofalse}
\makeatother

\ifdifffonts
\RequirePackage{aurical}\RequirePackage{kpfonts}\RequirePackage[euler-digits]{eulervm}
\fi

\providecommand{\UEAuthors}{}
\providecommand{\UEMatNo}{}
\providecommand{\UEName}{}
\providecommand{\UENameShort}{}
\providecommand{\UETerm}{}
\providecommand{\UEBlatt}{}
\providecommand{\UEAufgabe}{}
\providecommand{\UEMPts}{}
\providecommand{\aufgaben}{}
\providecommand{\points}{}
\providecommand{\maxpoints}{}
\providecommand{\maxpunkt}{}
\providecommand{\UELogo}{img/i3logo.png}
\providecommand{\UELogoOptions}{30mm}
\providecommand{\UERueckgabe}{\vspace*{1.5cm}}


\RequirePackage{xparse}
\ProvideDocumentCommand{\lecture}{ O{img/i3logo.png} O{width=30mm} m m }{
	\renewcommand{\UELogoOptions}{#2}
	\renewcommand{\UELogo}{#1}
	\renewcommand{\UENameShort}{#3}
	\renewcommand{\UEName}{#4}
}


\providecommand{\term}[1]{\renewcommand{\UETerm}{#1}}
\providecommand{\rueckgabe}[1]{\renewcommand{\UERueckgabe}{Rückgabe erbeten in Gruppe:\\\begin{center}#1\end{center}}}

\fancypagestyle{plain}{
	\fancyhf{} % remove everything
    \fancyheadoffset[L]{1cm}
    \ifdoublelogo
	\lhead{\qquad\qquad\includegraphics[width=60mm]{\UELogo}}
    \else
	\lhead{\qquad\qquad\includegraphics[width=50mm]{\UELogo}}
    \fi
	\rhead{\includegraphics[width=2.95in]{img/fau-logo-deutsch.pdf}}
	\renewcommand{\headrulewidth}{0pt} % remove lines as well
	\renewcommand{\footrulewidth}{0pt}
}

\pagestyle{fancy}
\fancyhf{}
\lhead{\UENameShort}
\chead{\UEBlatt\ifsingleex, \UEAufgabe\else\fi}
\rhead{\UETerm}
\lfoot{Seite \thepage}
\cfoot{}
\rfoot{}

\ifsingleex
\DeclareDocumentCommand{\uebungsblatt}{m m m m}{\renewcommand{\UEBlatt}{Übungsblatt #1}\renewcommand{\UEAufgabe}{Aufgabe #2}\renewcommand{\UEMPts}{#3}
		\renewcommand{\UEAuthors}{#4}}
\else
\providecommand{\uebungsblatt}[5]{
	\renewcommand{\UEBlatt}{Übungsblatt #1}
	\renewcommand{\aufgaben}{#2}
	\renewcommand{\points}{#3}
	\renewcommand{\maxpunkt}{#4}
	\renewcommand{\UEAuthors}{#5}
}
\fi

\newenvironment{vartab}[1]
{\begin{tabular}{ c | *{#1}{|c} || c }}
	{\end{tabular}}

\newcounter{clength}%
\newcommand{\length}[1]{%
	\setcounter{clength}{0}%
	\renewcommand*{\do}[1]{\stepcounter{clength}\vphantom{##1}}%
	\expandafter\docsvlist\expandafter{#1}%
	\phantom{\arabic{clength}}%
}

\renewcommand*{\do}[1]{& #1}
\newcommand{\maxDo}[1]{& $\nicefrac{\hspace*{1.25cm}}{#1}$}


\renewcommand{\maketitle}{%
	\renewcommand*{\do}[1]{& ##1}
	\renewcommand{\maxDo}[1]{& $\nicefrac{\hspace*{1.25cm}}{##1}$}
	\newgeometry{footskip=10pt, left=1cm,right=1cm,top=2.54cm,bottom=1cm}
    \thispagestyle{plain}
	\vspace*{0.1cm}
	\begin{center}
		Friedrich-Alexander-Universität Erlangen-Nürnberg\\[0.6cm]
		\textbf{\LARGE Übungen zur Vorlesung\\ \UEName}\\[0.6cm]
		{\large \UEBlatt} \ifsingleex\else\length{\aufgaben}\fi
	\end{center}
	\vspace*{2.8cm}
	\ifmatrikelnummer
    	\ifstudiengang
			\ifstudon
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lcccc}
						\underline{Name}, Vorname & Matrikelnummer & Studiengang & StudOn-Kennung & Übungsgruppe \\\midrule
    	    			\UEAuthors
					\end{tabular}
				\end{center}
			\else
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lccc}
						\underline{Name}, Vorname & Matrikelnummer & Studiengang & Übungsgruppe \\\midrule
						\UEAuthors
					\end{tabular}
				\end{center}
			\fi
    	\else
    		\ifstudon
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lccc}
						\underline{Name}, Vorname & Matrikelnummer & StudOn-Kennung & Übungsgruppe \\\midrule
    				    \UEAuthors
					\end{tabular}
				\end{center}
			\else
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lcc}
						\underline{Name}, Vorname & Matrikelnummer & Übungsgruppe \\\midrule
						\UEAuthors
					\end{tabular}
				\end{center}
			\fi
    	\fi
    \else
    	\ifstudiengang
			\ifstudon
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lccc}
						\underline{Name}, Vorname & Studiengang & StudOn-Kennung & Übungsgruppe \\\midrule
    	    			\UEAuthors
					\end{tabular}
				\end{center}
			\else
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lcc}
						\underline{Name}, Vorname & Studiengang & Übungsgruppe \\\midrule
						\UEAuthors
					\end{tabular}
				\end{center}
			\fi
    	\else
    		\ifstudon
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lcc}
						\underline{Name}, Vorname & StudOn-Kennung & Übungsgruppe \\\midrule
    	    			\UEAuthors
					\end{tabular}
				\end{center}
			\else
				\UEGroupIntr:\\
				\begin{center}
					\begin{tabular}{lc}
						\underline{Name}, Vorname & Übungsgruppe \\\midrule
						\UEAuthors
					\end{tabular}
				\end{center}
			\fi
    	\fi
    \fi
	\vspace*{2cm}
	\UERueckgabe
	\vspace*{7cm}
	\ifsingleex
	{\begin{center}\large Der Studierende hat $\rule{1cm}{0.5mm}$ von \UEMPts{} Punkten erzielt.\end{center}}
	\else
	{ \large
		\begin{center}
			\begin{vartab}{\theclength}
				Aufgabe \expandafter\docsvlist\expandafter{\aufgaben} & $\Sigma$ \\\hline
				Erreichbare Punkte \expandafter\docsvlist\expandafter{\points} & \maxpunkt \\\hline 
				Erreichte Puntke \expandafter\forcsvlist\expandafter\maxDo\expandafter{\points} & $\nicefrac{\hspace*{1cm}}{\maxpunkt}$
			\end{vartab}
	\end{center}}
	\fi
	\clearpage
	\restoregeometry
}
